(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       150,          7]
NotebookDataLength[    127681,       3549]
NotebookOptionsPosition[    126348,       3503]
NotebookOutlinePosition[    126691,       3518]
CellTagsIndexPosition[    126648,       3515]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"3", "/", "2"}], " ", "Stochastic", " ", "Volatility", " ", 
    "Model"}], "Title",
   FontVariations->{"Underline"->True}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
   "This", " ", "file", " ", "implements", " ", "3", "rd", " ", "order", " ", 
    "implied", " ", "vol", " ", "expansion", " ", "and", " ", "Fourier", " ", 
    "pricing", " ", "formula", " ", "for", " ", 
    RowBox[{"3", "/", "2"}], "model"}], "Subsection"], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dS", " ", "=", " ", 
   RowBox[{
    SqrtBox["Z"], "S", " ", "dW"}]}], "Subsection"], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{"dZ", " ", "=", " ", 
    RowBox[{"Z", " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Kappa]", 
        RowBox[{"(", 
         RowBox[{"\[Theta]", "-", "Z"}], ")"}], " ", "dt"}], " ", "+", " ", 
       RowBox[{"\[Delta]", " ", 
        SqrtBox["Z"], "dB"}]}], " ", ")"}]}]}], "Subsection"], 
  StyleBox[" ", "Subsection"]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"dW", " ", "dB"}], " ", "=", " ", 
    RowBox[{"\[Rho]", " ", "dt"}]}], "Subsection"], 
  StyleBox[" ", "Subsection"]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"X", " ", "=", " ", 
   RowBox[{"Log", "[", "S", "]"}]}], "Subsection"], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{"Y", " ", "=", " ", 
    RowBox[{"Log", "[", "Z", "]"}]}], "Subsection"], 
  StyleBox[" ", "Subsection"]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{"dX", " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", "1", " "}], "2"], 
      RowBox[{"Exp", "[", "Y", "]"}], " ", "dt"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{"Y", "/", "2"}], "]"}], " ", "dW"}]}]}], "Subsection"], 
  StyleBox[" ", "Subsection"]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dY", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Kappa]", 
        RowBox[{"(", 
         RowBox[{"\[Theta]", "-", 
          RowBox[{"Exp", "[", "Y", "]"}]}], ")"}]}], " ", "-", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[Delta]", "^", "2"}], " ", 
        RowBox[{"Exp", "[", "Y", "]"}]}]}], " ", ")"}], " ", "dt"}], " ", "+",
     " ", 
    RowBox[{"\[Delta]", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"Y", "/", "2"}], "]"}], " ", "dB", " "}]}]}], 
  "Subsection"]}], "Input",
 CellChangeTimes->{{3.5797090952070107`*^9, 3.5797091290439463`*^9}, {
  3.5797091741585264`*^9, 3.579709193689644*^9}, {3.58046151483314*^9, 
  3.5804615151919403`*^9}, {3.5804615470783963`*^9, 3.5804615600108194`*^9}, {
  3.5804616141468096`*^9, 3.5804616317280407`*^9}, {3.580789307839188*^9, 
  3.5807893127844515`*^9}, {3.5807913077519827`*^9, 3.5807913081887827`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Disclaimer", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}}],

Cell["\<\
Date: June 21, 2013.

This file was created by: Matthew Lorig, Stefano Pagliarani and Andrea \
Pascucci.

These Mathematica notebooks are provided on an \[OpenCurlyDoubleQuote]as is\
\[CloseCurlyDoubleQuote] basis without warranty of any kind, express or \
implied. Under no circumstances and under no legal theory, whether in tort, \
contract, or otherwise, shall the authors be liable to you or to any other \
person for any indirect, special, incidental, or consequential damages or \
losses. If you do not agree with these terms, then you are advised to not use \
the notebooks.

Please do no redistribute these notebooks.  If you wish to endorse the \
notebooks, then please link to the web-pages of the authors:
http://www.princeton.edu/~mlorig/
http://www.math.unipd.it/~stefanop/
http://www.dm.unibo.it/~pascucci/\
\>", "Text",
 CellChangeTimes->{{3.5127369954359856`*^9, 3.512737125359417*^9}, {
   3.5127371655637164`*^9, 3.5127371663597617`*^9}, {3.512814058730217*^9, 
   3.512814058891226*^9}, 3.526199505602*^9, 3.5268335032155323`*^9, {
   3.5272388928125*^9, 3.527238893671875*^9}, {3.5804506352987995`*^9, 
   3.580450646016018*^9}, 3.5804510585431423`*^9, {3.5804621210085855`*^9, 
   3.5804621221941876`*^9}, {3.580791299686783*^9, 3.580791299827183*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}, 
   3.580451009169056*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}], " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cc", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]\[Alpha]", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"\[Kappa]", 
      RowBox[{"(", 
       RowBox[{"\[Theta]", "-", 
        RowBox[{"Exp", "[", "y", "]"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"\[Delta]", "^", "2"}], " ", 
      RowBox[{"Exp", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Compute"}]}]}]}]}]}]}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Coefficients", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], "  ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["aa", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"3", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["bb", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"3", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["cc", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"3", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "3"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Alpha]\[Alpha]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Get"}]}]}]}]}]}]}], " ", "Implied", " ", "Vol", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Expansion", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Define"}]}]}]}]}]}]}], " ", "3", "rd", " ", 
    "order", " ", "Implied", " ", "Vol", " ", "Expansion", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]0", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]00", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]1", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]10", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]01", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]2", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]20", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]11", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]02", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]3", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]30", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]21", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]12", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]03", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"-", " ", "3"}]}]}]}]}]}], "/", "2"}], " ", "Call", " ", 
     "Price"}], " ", "+", " ", 
    RowBox[{"True", " ", "Implied", " ", "Vol", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]Three", " ", "--"}], "--"}], "--"}], "--"}], 
       "--"}], "--"}]}], "-"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Call", "[", 
    RowBox[{
    "t_", ",", "x_", ",", "k_", ",", "\[Kappa]_", ",", "\[Delta]_", ",", 
     "\[Rho]_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "p", ",", "q", ",", "\[Alpha]0", ",", "\[Gamma]", ",", "\[CapitalPhi]0",
        ",", "h", ",", "z", ",", "\[Lambda]i"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"-", "\[Kappa]"}], " ", "+", " ", 
        RowBox[{
        "\[ImaginaryI]", " ", "\[Delta]", " ", "\[Rho]", " ", 
         "\[Lambda]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"q", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Lambda]"}], " ", "+", " ", 
          RowBox[{"\[Lambda]", "^", "2"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Alpha]0", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "-", 
           FractionBox[
            RowBox[{"p", "[", "\[Lambda]", "]"}], 
            RowBox[{"\[Delta]", "^", "2"}]]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "-", 
             FractionBox[
              RowBox[{"p", "[", "\[Lambda]", "]"}], 
              RowBox[{"\[Delta]", "^", "2"}]]}], ")"}], "^", "2"}], "+", 
          RowBox[{"2", " ", 
           FractionBox[
            RowBox[{"q", "[", "\[Lambda]", "]"}], 
            RowBox[{"\[Delta]", "^", "2"}]]}]}]]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Gamma]", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], "+", "1", "-", 
          FractionBox[
           RowBox[{"p", "[", "\[Lambda]", "]"}], 
           RowBox[{"\[Delta]", "^", "2"}]]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"z", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"Exp", "[", "y", "]"}], 
         RowBox[{"\[Kappa]", " ", "\[Theta]"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"\[Kappa]", " ", "\[Theta]", " ", "t"}], "]"}], "-", "1"}],
          ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[CapitalPhi]0", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"\[ImaginaryI]", " ", "\[Lambda]", " ", "x"}], "]"}], 
        FractionBox[
         RowBox[{"Gamma", "[", 
          RowBox[{
           RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], "-", 
           RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}]}], "]"}], 
         RowBox[{"Gamma", "[", 
          RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], "]"}]], 
        RowBox[{
         RowBox[{"(", 
          FractionBox["2", 
           RowBox[{
            RowBox[{"\[Delta]", "^", "2"}], " ", "z"}]], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], ")"}]}], 
        RowBox[{"Hypergeometric1F1", "[", 
         RowBox[{
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], ",", 
          RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], ",", 
          FractionBox[
           RowBox[{"-", "2"}], 
           RowBox[{
            RowBox[{"\[Delta]", "^", "2"}], " ", "z"}]]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"h", "[", "\[Lambda]_", "]"}], "=", 
       FractionBox[
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"k", "-", 
           RowBox[{"\[ImaginaryI]", " ", "k", " ", "\[Lambda]"}]}]]}], 
        RowBox[{" ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "\[Lambda]"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Lambda]i", "=", 
       RowBox[{"-", "1.25"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"Chop", "[", 
        RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[CapitalPhi]0", "[", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Lambda]i"}]}], "]"}], 
            RowBox[{"h", "[", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Lambda]i"}]}], "]"}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]", ",", 
            RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
          RowBox[{"Method", " ", "->", "\"\<GlobalAdaptive\>\""}], ",", 
          RowBox[{"Exclusions", "\[Rule]", "0"}], ",", 
          RowBox[{"WorkingPrecision", " ", "\[Rule]", "13"}]}], "]"}], 
        "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", "[", "z_", "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"NumericQ", "[", "z", "]"}], "&&", 
        RowBox[{"z", "<", "0"}]}], ",", 
       RowBox[{"Erfc", "[", 
        RowBox[{
         RowBox[{"-", "z"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}], ",", 
       RowBox[{"1", "+", 
        RowBox[{"Erf", "[", 
         RowBox[{"z", "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}]}]}], "]"}], "/", "2"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PBS", "[", 
    RowBox[{"t_", ",", "x_", ",", "k_", ",", "\[Sigma]_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d1", ",", "d2"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"d1", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "k", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Sigma]", "^", "2"}], "/", "2"}], ")"}], "t"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}]}], ";", "\n", "\t", 
      RowBox[{"d2", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "k", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Sigma]", "^", "2"}]}], "/", "2"}], ")"}], "t"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}]}], ";", "\n", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", "x", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "d1", "]"}]}], "-", 
       RowBox[{
        RowBox[{"Exp", "[", "k", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "d2", "]"}]}]}]}]}], "\n", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImpVol", "[", 
    RowBox[{"CallPrice_", ",", "t_", ",", "x_", ",", "k_"}], "]"}], ":=", " ", 
   RowBox[{"FinancialDerivative", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<European\>\"", ",", " ", "\"\<Call\>\""}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<StrikePrice\>\"", " ", "->", " ", 
        RowBox[{"Exp", "[", "k", "]"}]}], ",", " ", 
       RowBox[{"\"\<Expiration\>\"", " ", "->", " ", "t"}], ",", " ", 
       RowBox[{"\"\<Value\>\"", " ", "->", " ", "CallPrice"}]}], "}"}], ",", 
     "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<InterestRate\>\"", " ", "->", " ", "0"}], ",", " ", 
       RowBox[{"\"\<CurrentPrice\>\"", " ", "\[Rule]", 
        RowBox[{"Exp", "[", "x", "]"}]}], ",", " ", 
       RowBox[{"\"\<Dividend\>\"", " ", "->", " ", "0"}]}], "}"}], ",", " ", 
     "\"\<ImpliedVolatility\>\""}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]Three", "[", 
     RowBox[{
     "t_", ",", "x_", ",", "k_", ",", "\[Kappa]_", ",", "\[Delta]_", ",", 
      "\[Rho]_", ",", "y_"}], "]"}], ":=", 
    RowBox[{"Quiet", "[", 
     RowBox[{"ImpVol", "[", 
      RowBox[{
       RowBox[{"Call", "[", 
        RowBox[{
        "t", ",", "x", ",", "k", ",", "\[Kappa]", ",", "\[Delta]", ",", 
         "\[Rho]", ",", "y"}], "]"}], ",", "t", ",", "x", ",", "k"}], "]"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", " ", "Choose"}]}]}]}]}]}]}], " ", 
     RowBox[{"3", "/", "2"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"parameters", " ", "--"}], "--"}], "--"}], "--"}], "--"}]}], 
    "-"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Kappa]", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]", "=", "0.2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]", "=", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"-", "0.8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "=", 
    RowBox[{"Log", "[", "\[Theta]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"-", "Implied"}]}]}]}]}]}], " ", "Vol", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Plots", " ", "--"}], "--"}], "--"}], "--"}], "--"}], 
     "--"}]}], "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", "x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y0", "=", "y"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmin", "=", 
   RowBox[{"-", "1.00"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmax", "=", "0.75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"knum", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kstp", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"kmax", "-", "kmin"}], ")"}], "/", "knum"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kmat", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"k", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "kmin", ",", "kmax", ",", "kstp"}], "}"}]}], "]"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Implied Vol: Exact (solid) vs 3rd order (dashed)\>\"", ",", "16", ",",
     "Blue", ",", "Bold"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Time to maturity = \>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"t", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"umat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Call", "[", 
      RowBox[{"t", ",", "x", ",", 
       RowBox[{"kmat", "[", 
        RowBox[{"[", "ii", "]"}], "]"}], ",", "\[Kappa]", ",", "\[Delta]", 
       ",", "\[Rho]", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"knum", "+", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IVmat", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kmat", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], ",", 
        RowBox[{"ImpVol", "[", 
         RowBox[{
          RowBox[{"umat", "[", 
           RowBox[{"[", "ii", "]"}], "]"}], ",", "t", ",", "x", ",", 
          RowBox[{"kmat", "[", 
           RowBox[{"[", "ii", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "1", ",", 
        RowBox[{"knum", "+", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]mat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kmat", "[", 
        RowBox[{"[", "ii", "]"}], "]"}], ",", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", 
         RowBox[{"kmat", "[", 
          RowBox[{"[", "ii", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"knum", "+", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Emat", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kmat", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Sigma]mat", "[", 
            RowBox[{"[", 
             RowBox[{"ii", ",", "2"}], "]"}], "]"}], "-", 
           RowBox[{"IVmat", "[", 
            RowBox[{"[", 
             RowBox[{"ii", ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
         RowBox[{"IVmat", "[", 
          RowBox[{"[", 
           RowBox[{"ii", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "1", ",", 
        RowBox[{"knum", "+", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IVmin", "=", 
   RowBox[{"\[Sigma]mat", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"knum", "+", "1"}], ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IVmax", "=", 
   RowBox[{"\[Sigma]mat", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"IVmat", ",", "\[Sigma]mat"}], "}"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "IVmin"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", " ", "Print"}]}]}]}]}]}], " ", "Implied", " ", 
    "Volatility", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Formula", " ", "--"}], "--"}], "--"}], "--"}], "--"}], 
       "--"}], "--"}], "--"}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}], " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cc", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]\[Alpha]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"\[Kappa]", 
     RowBox[{"(", 
      RowBox[{"\[Theta]", "-", 
       RowBox[{"Exp", "[", "y", "]"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"\[Delta]", "^", "2"}], " ", 
     RowBox[{"Exp", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"To", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]0", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]00", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]1", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]10", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]01", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]2", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]20", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]11", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]02", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]3", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]30", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]21", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]12", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]03", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]0", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]1", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]2", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]3", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Third Order Implied Volatility Approximation\>\"", ",", "16", ",", 
    "Blue", ",", "Bold"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<\[Sigma] = \!\(\*SubscriptBox[\(\[Sigma]\), \(0\)]\) + \
\!\(\*SubscriptBox[\(\[Sigma]\), \(1\)]\) + \!\(\*SubscriptBox[\(\[Sigma]\), \
\(2\)]\) + \!\(\*SubscriptBox[\(\[Sigma]\), \(3\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(0\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(1\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(2\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(3\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<----------------\>\"", "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Manipulate", "  ", "--"}], "--"}], "--"}], "--"}], 
             "--"}], "--"}], "--"}], "--"}]}]}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}], " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cc", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
    RowBox[{"Exp", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]\[Alpha]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"\[Kappa]", 
     RowBox[{"(", 
      RowBox[{"\[Theta]", "-", 
       RowBox[{"Exp", "[", "y", "]"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"\[Delta]", "^", "2"}], " ", 
     RowBox[{"Exp", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]0", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]00", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]1", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]10", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]01", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]2", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]20", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]11", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]02", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]3", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]30", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]21", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]12", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]03", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", 
     RowBox[{
     "t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_", ",", 
      "\[Kappa]_", ",", "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", "x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmin", "=", 
   RowBox[{"-", "0.75"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmax", "=", "0.75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Implied Vol: 3rd Order (dashed)\>\"", ",", "16", ",", "Blue", ",", 
    "Bold"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{
       "t", ",", "x", ",", "y", ",", "x0", ",", "y", ",", "k", ",", 
        "\[Kappa]", ",", "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "kmin", ",", "kmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.0"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Delta]", ",", "0.5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Kappa]", ",", "1.0", ",", "10.0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0.25", ",", "0.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"Log", "[", "0.05", "]"}], ",", 
     RowBox[{"Log", "[", "0.2", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Rho]", ",", 
     RowBox[{"-", "0.9"}], ",", "0.9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0.01", ",", "0.4"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5764919506094313`*^9, 3.5764919551766925`*^9}, {
   3.5764920277388425`*^9, 3.5764923793689547`*^9}, {3.57649243365906*^9, 
   3.5764924611686335`*^9}, {3.5764925092163815`*^9, 3.5764925165408*^9}, {
   3.576492573216042*^9, 3.576492575420168*^9}, {3.5764926294472585`*^9, 
   3.576492858037333*^9}, {3.5764929496925755`*^9, 3.5764929915949717`*^9}, {
   3.5764930233557887`*^9, 3.576493070042459*^9}, {3.5764931031483526`*^9, 
   3.5764931936075263`*^9}, {3.5764932366559887`*^9, 
   3.5764932372540226`*^9}, {3.576493280358488*^9, 3.576493334976612*^9}, {
   3.576493370408639*^9, 3.5764933944110117`*^9}, 3.5764934345293064`*^9, {
   3.576493472324468*^9, 3.5764935165439973`*^9}, {3.5764935607595263`*^9, 
   3.576493622247043*^9}, {3.576493657747074*^9, 3.5764936578310785`*^9}, {
   3.5764939624475017`*^9, 3.5764939842747498`*^9}, {3.5764940931489773`*^9, 
   3.576494117521371*^9}, {3.576494164550061*^9, 3.5764942686680164`*^9}, {
   3.5764943035230103`*^9, 3.57649438744281*^9}, {3.5764944302792597`*^9, 
   3.5764944308122907`*^9}, {3.576494525762721*^9, 3.576494572489394*^9}, {
   3.576494615017826*^9, 3.576494679571519*^9}, {3.576494720746874*^9, 
   3.5764947664904904`*^9}, {3.5764948084178886`*^9, 
   3.5764948190294952`*^9}, {3.5764948547825403`*^9, 3.576494887717424*^9}, {
   3.5764949811417675`*^9, 3.576495095613315*^9}, {3.5764951328274436`*^9, 
   3.576495204115521*^9}, {3.5764952366803837`*^9, 3.576495285240161*^9}, {
   3.5764953674918656`*^9, 3.576495398809657*^9}, {3.5764954323525753`*^9, 
   3.576495507575878*^9}, {3.5764955383596387`*^9, 3.5764955661242266`*^9}, {
   3.5764957032410693`*^9, 3.5764957208610773`*^9}, {3.57649583263247*^9, 
   3.576495834495577*^9}, {3.5764958874336042`*^9, 3.576495889610729*^9}, 
   3.576495945981953*^9, {3.5765163083856163`*^9, 3.5765163213353567`*^9}, {
   3.5765764216688995`*^9, 3.576576495598128*^9}, {3.5765765390486135`*^9, 
   3.5765766097926593`*^9}, {3.576576657808406*^9, 3.576576660349551*^9}, {
   3.576576755206977*^9, 3.5765767613313265`*^9}, 3.576576810575144*^9, {
   3.5765768571998105`*^9, 3.5765768812421856`*^9}, {3.5765769694362297`*^9, 
   3.5765770630835857`*^9}, {3.5765770938833475`*^9, 
   3.5765771283383183`*^9}, {3.5765915383065214`*^9, 3.576591543980846*^9}, {
   3.57659157779078*^9, 3.5765916323459005`*^9}, {3.576591666558857*^9, 
   3.576591720403937*^9}, {3.576591751277703*^9, 3.576591778969287*^9}, 
   3.576593028368748*^9, {3.576687682687666*^9, 3.5766876833507037`*^9}, {
   3.5771129630135655`*^9, 3.5771130143795033`*^9}, {3.577113079227213*^9, 
   3.577113099066347*^9}, {3.5771131491922145`*^9, 3.577113204266364*^9}, {
   3.577113258796483*^9, 3.577113258991494*^9}, {3.5774641440919743`*^9, 
   3.5774641760538025`*^9}, 3.577464216238101*^9, {3.577465435044812*^9, 
   3.5774656696502314`*^9}, {3.5774657150418277`*^9, 
   3.5774658289703436`*^9}, {3.577465874137927*^9, 3.577465991658649*^9}, {
   3.5774660268986645`*^9, 3.577466125490304*^9}, {3.5774662413539305`*^9, 
   3.5774663017353845`*^9}, 3.577466383025034*^9, 3.577466483766796*^9, {
   3.5774665776111636`*^9, 3.5774665809863567`*^9}, {3.577466886188813*^9, 
   3.577466900727645*^9}, {3.5778141004973354`*^9, 3.5778141149901648`*^9}, {
   3.577814268006917*^9, 3.5778143258412247`*^9}, {3.5778150278923798`*^9, 
   3.5778150443803225`*^9}, {3.578045967191126*^9, 3.578046217556446*^9}, {
   3.5780462807160587`*^9, 3.578046281101081*^9}, {3.578047010027629*^9, 
   3.5780470152026362`*^9}, {3.578048165080246*^9, 3.578048184840274*^9}, 
   3.578049210896739*^9, {3.5780494821621184`*^9, 3.578049529538185*^9}, {
   3.5780495634932327`*^9, 3.578049627553322*^9}, {3.578049672348385*^9, 
   3.578049760473508*^9}, {3.578049796588559*^9, 3.578049826708601*^9}, {
   3.5780498920536923`*^9, 3.5780499687938*^9}, {3.578050176779091*^9, 
   3.578050187399106*^9}, {3.5780505044745493`*^9, 3.578050505164551*^9}, {
   3.5780505454646072`*^9, 3.5780505516596155`*^9}, {3.5780506129397016`*^9, 
   3.578050619634711*^9}, {3.578050667214778*^9, 3.5780507236948566`*^9}, 
   3.578050766619917*^9, {3.578050807429974*^9, 3.5780508141949835`*^9}, 
   3.57805095471518*^9, {3.5780510148602643`*^9, 3.578051032310289*^9}, {
   3.578051359485747*^9, 3.5780513624257507`*^9}, {3.5780514052508106`*^9, 
   3.5780514199108315`*^9}, 3.578051510490958*^9, {3.5780515787360535`*^9, 
   3.578051596316078*^9}, {3.578051673621189*^9, 3.5780516881062093`*^9}, {
   3.5780518536864414`*^9, 3.578051883846483*^9}, {3.578051966276599*^9, 
   3.578051984586624*^9}, 3.5780520408967032`*^9, {3.5780523168270893`*^9, 
   3.578052333477113*^9}, {3.5780524413622637`*^9, 3.578052448717274*^9}, {
   3.578052507562357*^9, 3.5780525130923643`*^9}, {3.57805257423245*^9, 
   3.5780525809174595`*^9}, {3.578052808457778*^9, 3.578052833682813*^9}, {
   3.5780529153679276`*^9, 3.578052921902937*^9}, {3.5780529722030067`*^9, 
   3.5780529997180457`*^9}, {3.578053113515473*^9, 3.5780531795063763`*^9}, 
   3.5780532106964197`*^9, {3.578053305186552*^9, 3.5780533326165905`*^9}, 
   3.5780534169267087`*^9, {3.5780541260087013`*^9, 3.57805414635373*^9}, {
   3.5780548728973184`*^9, 3.5780548752685223`*^9}, 3.578057153104125*^9, {
   3.578058683092635*^9, 3.578058841172677*^9}, {3.578058900867091*^9, 
   3.578058901346119*^9}, {3.5780593838377156`*^9, 3.5780593865018682`*^9}, {
   3.578059789670928*^9, 3.578059820734705*^9}, {3.5780598629691205`*^9, 
   3.57805989792512*^9}, {3.5780601770780864`*^9, 3.578060215578288*^9}, {
   3.5780604119055176`*^9, 3.57806042226311*^9}, {3.5783171459952726`*^9, 
   3.5783172169143295`*^9}, {3.578317295416819*^9, 3.578317298246981*^9}, {
   3.578317332351932*^9, 3.578317345186666*^9}, 3.578317399548775*^9, {
   3.5783174457834196`*^9, 3.5783175045867834`*^9}, {3.5783176054335513`*^9, 
   3.5783176145520725`*^9}, {3.57831764527383*^9, 3.5783176694532127`*^9}, {
   3.578317712073651*^9, 3.578317770379986*^9}, {3.57831782920035*^9, 
   3.578317840406991*^9}, {3.5783179444959445`*^9, 3.5783179632010145`*^9}, {
   3.578318042488549*^9, 3.5783180782255936`*^9}, {3.5783181864647846`*^9, 
   3.578318233156455*^9}, {3.578318519434829*^9, 3.578318525900199*^9}, {
   3.5783185932500515`*^9, 3.578318598583356*^9}, {3.578318680511042*^9, 
   3.5783186871414213`*^9}, 3.5783187213573785`*^9, 3.578318934837589*^9, 
   3.578319040248618*^9, {3.578319145248624*^9, 3.578319177162449*^9}, {
   3.57831937281964*^9, 3.5783193740207086`*^9}, {3.578319498016801*^9, 
   3.5783195006079493`*^9}, 3.578319597860512*^9, {3.578319786613308*^9, 
   3.578319797445927*^9}, {3.57831982792467*^9, 3.578319835396098*^9}, 
   3.578319959985224*^9, {3.578492699259345*^9, 3.5784927097009425`*^9}, {
   3.578492846975794*^9, 3.5784928474688225`*^9}, {3.578746772717516*^9, 
   3.57874677296953*^9}, {3.578746810291665*^9, 3.5787470033877096`*^9}, {
   3.5787471175202374`*^9, 3.5787471359972944`*^9}, {3.578747363162287*^9, 
   3.5787474285020247`*^9}, {3.5787476048891134`*^9, 3.578747630650587*^9}, {
   3.5787477758968945`*^9, 3.5787477934769*^9}, 3.578747844454816*^9, {
   3.5787482181451893`*^9, 3.578748419005678*^9}, {3.5787484596660037`*^9, 
   3.578748468433505*^9}, {3.578749404194028*^9, 3.578749514451334*^9}, {
   3.578749582061201*^9, 3.5787497147887926`*^9}, {3.578749745447546*^9, 
   3.5787497715380383`*^9}, {3.578749802266796*^9, 3.578749824800085*^9}, {
   3.5787499495142183`*^9, 3.5787499549515295`*^9}, {3.578749997998991*^9, 
   3.5787500564863367`*^9}, {3.578750095743582*^9, 3.5787502395208054`*^9}, {
   3.5787502781580153`*^9, 3.5787503244366627`*^9}, 3.5787503590056396`*^9, {
   3.578750446934669*^9, 3.578750476964387*^9}, 3.578750507363125*^9, {
   3.578750553294752*^9, 3.578750606368788*^9}, {3.578750728172755*^9, 
   3.5787507307529025`*^9}, {3.578750776095496*^9, 3.578750782301851*^9}, {
   3.5787508144896917`*^9, 3.578750823667217*^9}, {3.578751553782977*^9, 
   3.578751579972475*^9}, {3.578751683284384*^9, 3.5787520721536264`*^9}, {
   3.5787524791979074`*^9, 3.578752487160363*^9}, {3.5787526147286596`*^9, 
   3.5787526159467297`*^9}, {3.5787528630758643`*^9, 
   3.5787528838490524`*^9}, {3.578753039701967*^9, 3.578753052127678*^9}, {
   3.5787531969989634`*^9, 3.5787532420305395`*^9}, {3.5787532722612686`*^9, 
   3.578753311386506*^9}, {3.578753343935368*^9, 3.5787533497026978`*^9}, {
   3.578753445411172*^9, 3.5787535236066446`*^9}, {3.578753812387162*^9, 
   3.578753816643405*^9}, 3.5787542313001223`*^9, {3.5787719483634806`*^9, 
   3.5787719896248407`*^9}, {3.57877207581477*^9, 3.5787721123908625`*^9}, 
   3.578772147904894*^9, {3.5787722027550306`*^9, 3.578772213769661*^9}, {
   3.5787729401732087`*^9, 3.578772946243556*^9}, {3.5787759225657916`*^9, 
   3.57877595033638*^9}, {3.578776109104461*^9, 3.578776109975511*^9}, {
   3.5787763126021004`*^9, 3.5787763152952547`*^9}, {3.57877637081243*^9, 
   3.5787763712394543`*^9}, {3.5787764070905046`*^9, 3.5787764572263727`*^9}, 
   3.578776491522334*^9, {3.5787765429362745`*^9, 3.578776552258808*^9}, {
   3.5787765985684566`*^9, 3.5787766704635687`*^9}, 3.5787767560574646`*^9, {
   3.5787768114296317`*^9, 3.5787769423571205`*^9}, 3.5787769787432013`*^9, {
   3.5787770289810753`*^9, 3.578777032841296*^9}, {3.5788355089449377`*^9, 
   3.578835534530401*^9}, 3.5788357927571707`*^9, {3.578836369139138*^9, 
   3.5788363815448475`*^9}, 3.5788364591192846`*^9, {3.578836513724408*^9, 
   3.5788366092388706`*^9}, {3.578836695605811*^9, 3.5788366983629684`*^9}, {
   3.578836752481064*^9, 3.5788367554812355`*^9}, {3.5793728178308363`*^9, 
   3.579372817948843*^9}, {3.5793728559290156`*^9, 3.579372874616084*^9}, 
   3.5793730949416866`*^9, {3.579373137701132*^9, 3.5793731467906523`*^9}, {
   3.579373383167172*^9, 3.57937348907923*^9}, {3.579373567623722*^9, 
   3.5793735677597303`*^9}, {3.579373708199763*^9, 3.57937370850378*^9}, 
   3.579373782613019*^9, {3.5793738548981533`*^9, 3.579373888376068*^9}, {
   3.5793739685426536`*^9, 3.5793739976333175`*^9}, {3.579374031332245*^9, 
   3.579374108032632*^9}, {3.579374280166477*^9, 3.57937428859896*^9}, {
   3.57937433913085*^9, 3.579374345178196*^9}, {3.5793744555295076`*^9, 
   3.5793745385832577`*^9}, 3.5793749517838917`*^9, {3.5793750375047946`*^9, 
   3.57937506522438*^9}, {3.579375119474483*^9, 3.579375126273872*^9}, {
   3.5793753746490784`*^9, 3.5793753889888983`*^9}, {3.5793757415820656`*^9, 
   3.5793757589460588`*^9}, {3.5793758853632894`*^9, 
   3.5793759064184933`*^9}, {3.579375984758974*^9, 3.579376004813122*^9}, {
   3.5793760776662884`*^9, 3.5793760964453626`*^9}, {3.5793761844383955`*^9, 
   3.5793762239976583`*^9}, 3.579376350530895*^9, {3.5793768941749897`*^9, 
   3.579376906735708*^9}, 3.579376946022956*^9, {3.5793771244751625`*^9, 
   3.57937713194659*^9}, {3.5793772014385643`*^9, 3.579377205271784*^9}, {
   3.5793774377030783`*^9, 3.5793774743561745`*^9}, {3.579379549118844*^9, 
   3.579379600164764*^9}, {3.5793796398520336`*^9, 3.5793796470484457`*^9}, {
   3.579390593986574*^9, 3.5793906060902667`*^9}, {3.5794425432484474`*^9, 
   3.5794425451355553`*^9}, {3.579442636210765*^9, 3.57944264050101*^9}, {
   3.579442817147114*^9, 3.5794429192049513`*^9}, {3.579442993350192*^9, 
   3.5794429952302995`*^9}, {3.5794431802068796`*^9, 
   3.5794432623235765`*^9}, {3.579443493533801*^9, 3.579443526984714*^9}, {
   3.579448124766692*^9, 3.5794481546284*^9}, 3.5794482037092075`*^9, {
   3.5794499975018063`*^9, 3.5794500449315195`*^9}, {3.5794500761513047`*^9, 
   3.579450092732253*^9}, 3.5794502706834316`*^9, {3.579450460623296*^9, 
   3.579450461364338*^9}, {3.5797005470030813`*^9, 3.5797006773765383`*^9}, {
   3.579700723757191*^9, 3.5797007399001145`*^9}, {3.5797007732470217`*^9, 
   3.5797009151301374`*^9}, {3.5797013403164563`*^9, 3.579701347469866*^9}, {
   3.5797015956800623`*^9, 3.5797016102978983`*^9}, 3.579701732113866*^9, 
   3.579702557217059*^9, {3.5797080845812063`*^9, 3.579708085836278*^9}, {
   3.5797091160792046`*^9, 3.579709138005459*^9}, {3.579788233405631*^9, 
   3.5797882554418917`*^9}, 3.579882631027551*^9, 3.580461598683287*^9, {
   3.580746931545006*^9, 3.580747047498638*^9}, 3.580747105614962*^9, {
   3.580747337609231*^9, 3.580747353358132*^9}, 3.580747389195182*^9, {
   3.5807475230598383`*^9, 3.5807475428189683`*^9}, {3.58074763166005*^9, 
   3.580747646323889*^9}, {3.5807477507948637`*^9, 3.580747777177373*^9}, {
   3.5807479071228056`*^9, 3.5807479403867083`*^9}, {3.5807480604165735`*^9, 
   3.5807480774275465`*^9}, {3.5807893392891912`*^9, 3.580789401892583*^9}, {
   3.580789479892583*^9, 3.580789494462983*^9}, {3.5807895758481827`*^9, 
   3.5807895821037827`*^9}, 3.580789649714183*^9, {3.5807897271837826`*^9, 
   3.5807897272305827`*^9}, {3.580789803233783*^9, 3.580789807242983*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"Implied Vol: Exact (solid) vs 3rd order (dashed)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791319810783*^9}],

Cell[BoxData["\<\"Time to maturity = \"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791319810783*^9}]
}, Open  ]],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.580791319810783*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf9rcllBdmz3tgbwwGb/effu/L/SfygX0aGLza
z22gn9cs9sB+1kwQeL5fL929mm/FffszYPBkv8LeuIWSqvftIeY92s/iv2Kz
0ZJ7UP339ps/dd6SrHoPqv7G/s+KgZbbVty1NwLbd3k/W/DpPmO9u/YGYP7p
/fX2z9Y92XrH/sd/ENi/f/0PI6dL9nfsFcDyi/frMSruYzpz234B2D0r7U33
X2RpiYLxD9qvktrjEvH6lv0FiIX2vZPr9DrrbtmzgN13xX7r89Ub5URu2c8B
q79p3/crcYX8mpv2JmDz79tvYqvrnuJ20z4D7P5H9s+43a+0PL4BlX9qv7l5
/ZkfTTfsIWH4wp5HeMX8Hyo37AHrR6F7
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf9k/J3NkdMe+BvTEYvN3Pc8CXpSHygX0aGLza
L3fqZdY60Qf2s2aCwPP9O/il648vvW9/Bgye7K/8VMjioHTfHmLeo/21NjdS
jy24B9V/b//Ft76LoxTvQdXf2J/DdnnPn8V37Y3A9l3eH9CWvmmNxl17AzD/
9P7aXO6WrPV37H/8B4H9+z/t3mdoZnHHXgEsv3j/+sLG3fyHb9svALtnpf32
vmDF7/4w/kF7DmHT5Df3btlfgFhov+CfauP7/Fv2LGD3XbFvDlSrZmC+ZT8H
rP6m/Vpus0D5GTftTcDm37dX1A1l9tG/aZ8Bdv8j+/tbmye2nbgBlX9q/3Dp
wd/nkm/YQ8Lwhb3ZXz4nVcYb9gCcWaFt
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.37506991816549673`},
  Method->{},
  PlotRange->{{-1., 0.7500000000000002}, {0.37506991816549673`, 
   0.5193383422984119}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.035, 0.035}, {0.0028853684826583036`, 
   0.0028853684826583036`}}]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.5807913305747833`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"Third Order Implied Volatility Approximation\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330605983*^9}],

Cell[BoxData["\<\"\[Sigma] = \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \
\\(0\\)]\\) + \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(1\\)]\\) + \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(2\\)]\\) + \\!\\(\\*SubscriptBox[\\(\
\[Sigma]\\), \\(3\\)]\\)\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330605983*^9}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(0\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330621583*^9}]
}, Open  ]],

Cell[BoxData[
 SqrtBox[
  SuperscriptBox["\[ExponentialE]", "y"]]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.580791330621583*^9}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(1\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330621583*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}], " ", "\[Delta]", " ", "\[Rho]"}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "y"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Delta]", "2"], "+", 
        RowBox[{"2", " ", "\[Kappa]"}], "-", 
        RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.580791330637183*^9}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(2\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330637183*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "48"]}], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], "2"], " ", 
   SuperscriptBox["\[Delta]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[Rho]", "2"]}], ")"}]}], "-", 
  RowBox[{
   FractionBox["1", "96"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}], " ", "\[Delta]", " ", "\[Rho]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["\[ExponentialE]", "y"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Delta]", "2"], "+", 
        RowBox[{"2", " ", "\[Kappa]"}], "-", 
        RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "384"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"20", " ", "t", " ", 
      SuperscriptBox["\[Theta]", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "y"}]], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"13", " ", 
         SuperscriptBox["\[Delta]", "4"]}], "+", 
        RowBox[{"52", " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]"}], "-", 
        RowBox[{"52", " ", "\[Delta]", " ", "\[Kappa]", " ", "\[Rho]"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Delta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"13", " ", "\[Kappa]"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", "y"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"18", " ", "t", " ", "\[Theta]", " ", 
         SuperscriptBox["\[Kappa]", "2"]}], "-", 
        RowBox[{
        "9", " ", "t", " ", "\[Delta]", " ", "\[Theta]", " ", "\[Kappa]", " ",
          "\[Rho]"}], "+", 
        RowBox[{
         SuperscriptBox["\[Delta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "+", 
           RowBox[{"9", " ", "t", " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
           RowBox[{"7", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.580791330730783*^9}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(3\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791330730783*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "384"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", "y"]], " ", "t", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], "2"], " ", 
   SuperscriptBox["\[Delta]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "y"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Delta]", "2"], "+", 
        RowBox[{"2", " ", "\[Kappa]"}], "-", 
        RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "8"}], "+", 
        SuperscriptBox["\[Rho]", "2"]}], ")"}]}], "-", 
     RowBox[{"2", " ", "\[Theta]", " ", "\[Kappa]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SuperscriptBox["\[Rho]", "2"]}], ")"}]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", "y"]], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], " ", "\[Delta]", " ", "\[Rho]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"20", " ", "t", " ", 
       SuperscriptBox["\[Theta]", "2"], " ", 
       SuperscriptBox["\[Kappa]", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["\[ExponentialE]", "y"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"14", " ", "t", " ", "\[Theta]", " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "-", 
         RowBox[{
         "7", " ", "t", " ", "\[Delta]", " ", "\[Theta]", " ", "\[Kappa]", 
          " ", "\[Rho]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"7", " ", "t", " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "y"}]], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"45", " ", 
          SuperscriptBox["\[Delta]", "4"]}], "+", 
         RowBox[{"180", " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "-", 
         RowBox[{"90", " ", 
          SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]"}], "-", 
         RowBox[{"180", " ", "\[Delta]", " ", "\[Kappa]", " ", "\[Rho]"}], 
         "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"45", " ", "\[Kappa]"}], "+", 
            RowBox[{"14", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
    "1536"], "-", 
  RowBox[{
   FractionBox["1", "3072"], 
   RowBox[{
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", "y"]], " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "t", " ", 
       SuperscriptBox["\[Theta]", "3"], " ", 
       SuperscriptBox["\[Kappa]", "3"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["\[ExponentialE]", "y"], " ", "\[Theta]", " ", 
       "\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"22", " ", "t", " ", "\[Theta]", " ", 
          SuperscriptBox["\[Kappa]", "2"]}], "-", 
         RowBox[{
         "11", " ", "t", " ", "\[Delta]", " ", "\[Theta]", " ", "\[Kappa]", 
          " ", "\[Rho]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "+", 
            RowBox[{"11", " ", "t", " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
            RowBox[{"14", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"3", " ", "y"}]], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"35", " ", 
          SuperscriptBox["\[Delta]", "6"]}], "+", 
         RowBox[{"280", " ", 
          SuperscriptBox["\[Kappa]", "3"]}], "-", 
         RowBox[{"105", " ", 
          SuperscriptBox["\[Delta]", "5"], " ", "\[Rho]"}], "-", 
         RowBox[{"420", " ", "\[Delta]", " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Rho]"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "+", 
            RowBox[{"210", " ", "\[Kappa]"}], "+", 
            RowBox[{"29", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Delta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "+", 
            RowBox[{"105", " ", "\[Kappa]"}], "+", 
            RowBox[{"64", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "16"}], "+", 
            RowBox[{"105", " ", "\[Kappa]"}], "+", 
            RowBox[{"64", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "y"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"52", " ", "t", " ", "\[Theta]", " ", 
          SuperscriptBox["\[Kappa]", "3"]}], "-", 
         RowBox[{"52", " ", "t", " ", "\[Delta]", " ", "\[Theta]", " ", 
          SuperscriptBox["\[Kappa]", "2"], " ", "\[Rho]"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "12"}], "+", 
            RowBox[{"13", " ", "t", " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Delta]", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "24"}], "+", 
            RowBox[{"13", " ", "t", " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", "\[Kappa]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "12"}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["\[Rho]", "2"]}], "+", 
            RowBox[{"t", " ", "\[Theta]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"13", " ", "\[Kappa]"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.580791331167583*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"----------------\"\>"], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791331167583*^9}],

Cell[BoxData[
 StyleBox["\<\"Implied Vol: 3rd Order (dashed)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{3.579700920578449*^9, 3.57970136835506*^9, 
  3.5797016116759777`*^9, 3.5797080967379017`*^9, 3.5797882753520308`*^9, 
  3.579882409964907*^9, 3.5798826394360323`*^9, 3.5807471352606573`*^9, 
  3.580747355052229*^9, 3.580747544982092*^9, 3.5807476480189857`*^9, 
  3.5807477803165526`*^9, 3.580747943526888*^9, 3.5807480791296434`*^9, 
  3.580789402875383*^9, 3.580789495102583*^9, 3.580789583226983*^9, 
  3.5807896504941826`*^9, 3.580789728026183*^9, 3.5807898091617827`*^9, 
  3.580791331214383*^9}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 
    0.01, $CellContext`y$$ = -2.995732273553991, $CellContext`\[Delta]$$ = 
    0.5, $CellContext`\[Theta]$$ = 0.25, $CellContext`\[Kappa]$$ = 
    1., $CellContext`\[Rho]$$ = -0.9, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Delta]$$], 0.5, 5}, {
      Hold[$CellContext`\[Kappa]$$], 1., 10.}, {
      Hold[$CellContext`\[Theta]$$], 0.25, 0.5}, {
      Hold[$CellContext`y$$], -2.995732273553991, -1.6094379124341003`}, {
      Hold[$CellContext`\[Rho]$$], -0.9, 0.9}, {
      Hold[$CellContext`t$$], 0.01, 0.4}}, Typeset`size$$ = {
    360., {115., 118.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Delta]$3278$$ = 
    0, $CellContext`\[Kappa]$3279$$ = 0, $CellContext`\[Theta]$3280$$ = 
    0, $CellContext`y$3281$$ = 0, $CellContext`\[Rho]$3282$$ = 
    0, $CellContext`t$3283$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`t$$ = 
        0.01, $CellContext`y$$ = -2.995732273553991, $CellContext`\[Delta]$$ = 
        0.5, $CellContext`\[Theta]$$ = 0.25, $CellContext`\[Kappa]$$ = 
        1., $CellContext`\[Rho]$$ = -0.9}, "ControllerVariables" :> {
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$3278$$, 0], 
        Hold[$CellContext`\[Kappa]$$, $CellContext`\[Kappa]$3279$$, 0], 
        Hold[$CellContext`\[Theta]$$, $CellContext`\[Theta]$3280$$, 0], 
        Hold[$CellContext`y$$, $CellContext`y$3281$$, 0], 
        Hold[$CellContext`\[Rho]$$, $CellContext`\[Rho]$3282$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$3283$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[{
         $CellContext`\[Sigma][$CellContext`t$$, $CellContext`x, \
$CellContext`y$$, $CellContext`x0, $CellContext`y$$, $CellContext`k, \
$CellContext`\[Kappa]$$, $CellContext`\[Theta]$$, $CellContext`\[Delta]$$, \
$CellContext`\[Rho]$$]}, {$CellContext`k, $CellContext`kmin, \
$CellContext`kmax}, PlotStyle -> {{Black, Dashed}}, AxesOrigin -> {0, 0.}], 
      "Specifications" :> {{$CellContext`\[Delta]$$, 0.5, 
         5}, {$CellContext`\[Kappa]$$, 1., 10.}, {$CellContext`\[Theta]$$, 
         0.25, 0.5}, {$CellContext`y$$, -2.995732273553991, \
-1.6094379124341003`}, {$CellContext`\[Rho]$$, -0.9, 0.9}, {$CellContext`t$$, 
         0.01, 0.4}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {229., 234.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5793760106844573`*^9, 3.5793769522893143`*^9, 
  3.5793772070988884`*^9, 3.5793774788764334`*^9, 3.579390629892628*^9, 
  3.579442549533807*^9, 3.579442997230414*^9, 3.579443269664996*^9, 
  3.5794435357382145`*^9, 3.5794482079624505`*^9, 3.579450095759426*^9, 
  3.5794502765477667`*^9, 3.5794507523759828`*^9, 3.579700920580449*^9, 
  3.5797013683570604`*^9, 3.5797016116779776`*^9, 3.5797080967399015`*^9, 
  3.5797882753540306`*^9, 3.5798824099669075`*^9, 3.579882639438032*^9, 
  3.5807471352646575`*^9, 3.580747355056229*^9, 3.5807475449880924`*^9, 
  3.5807476480259857`*^9, 3.5807477803225527`*^9, 3.580747943532888*^9, 
  3.580748079133644*^9, 3.580789402875383*^9, 3.580789495102583*^9, 
  3.580789583226983*^9, 3.5807896504941826`*^9, 3.580789728026183*^9, 
  3.5807898091617827`*^9, 3.5807913318071833`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1690, 945},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[550, 20, 2932, 81, 392, "Input"],
Cell[CellGroupData[{
Cell[3507, 105, 173, 3, 68, "Section"],
Cell[3683, 110, 1284, 25, 220, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5004, 140, 189, 4, 68, "Section"],
Cell[CellGroupData[{
Cell[5218, 148, 93085, 2738, 6564, "Input"],
Cell[CellGroupData[{
Cell[98328, 2890, 848, 17, 26, "Print"],
Cell[99179, 2909, 575, 8, 23, "Print"]
}, Open  ]],
Cell[99769, 2920, 867, 12, 31, "Output"],
Cell[100639, 2934, 2198, 41, 249, "Output"],
Cell[CellGroupData[{
Cell[102862, 2979, 844, 17, 26, "Print"],
Cell[103709, 2998, 778, 11, 23, "Print"],
Cell[104490, 3011, 621, 9, 23, "Print"]
}, Open  ]],
Cell[105126, 3023, 916, 14, 39, "Output"],
Cell[106045, 3039, 621, 9, 23, "Print"],
Cell[106669, 3050, 1564, 34, 46, "Output"],
Cell[108236, 3086, 621, 9, 23, "Print"],
Cell[108860, 3097, 3566, 90, 46, "Output"],
Cell[112429, 3189, 621, 9, 23, "Print"],
Cell[113053, 3200, 7797, 196, 107, "Output"],
Cell[CellGroupData[{
Cell[120875, 3400, 572, 8, 23, "Print"],
Cell[121450, 3410, 831, 17, 26, "Print"]
}, Open  ]],
Cell[122296, 3430, 4024, 69, 512, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature jwTrhYIM#laFtDw5zEnshuXb *)
