(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       150,          7]
NotebookDataLength[    155847,       4625]
NotebookOptionsPosition[    154611,       4586]
NotebookOutlinePosition[    154976,       4602]
CellTagsIndexPosition[    154933,       4599]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"SABR", " ", "Local"}], "-", 
    RowBox[{"Stochastic", " ", "Volatility", " ", "Model"}]}], "Title",
   FontVariations->{"Underline"->True}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
  "This", " ", "file", " ", "implements", " ", "3", "rd", " ", "order", " ", 
   "implied", " ", "vol", " ", "expansion", " ", "for", " ", "SABR", " ", 
   "model"}], "Subsection"], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"Compares", " ", "to", " ", "Hagan"}], ",", "Kumar", ",", 
    "Lesniewski", ",", 
    RowBox[{"and", " ", "Woodward", " ", "expansion"}]}], 
   "\[IndentingNewLine]"}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dS", " ", "=", " ", 
   RowBox[{"Z", " ", 
    RowBox[{"S", "^", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", "-", "1"}], ")"}]}], " ", "S", " ", "dW"}]}], 
  "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dZ", " ", "=", " ", 
   RowBox[{"\[Delta]", " ", "Z", " ", "dB"}]}], 
  "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"dW", " ", "dB"}], " ", "=", " ", 
   RowBox[{"\[Rho]", " ", "dt"}]}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"X", " ", "=", " ", 
   RowBox[{"Log", "[", "S", "]"}]}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"Y", " ", "=", " ", 
   RowBox[{"Log", "[", "Z", "]"}]}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dX", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"2", "Y"}], " ", "+", " ", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "1"}], ")"}], "X"}]}], "]"}], " ", "dt"}], 
    " ", "+", " ", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{"Y", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "1"}], ")"}], "X"}]}], "]"}], " ", 
     "dW"}]}]}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"dZ", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{"\[Delta]", "^", "2"}], " ", "dt"}], " ", "+", " ", 
    RowBox[{"\[Delta]", " ", "dB"}]}]}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"\[Delta]", ">", "0"}], "Subsection"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"0", " ", "<", " ", "\[Beta]", " ", "<", " ", "1"}], 
  "Subsection"]}], "Input",
 CellChangeTimes->{{3.5797092366040983`*^9, 3.579709323128047*^9}, {
  3.580461743066722*^9, 3.58046175936875*^9}, {3.5804618642321343`*^9, 
  3.5804618647937355`*^9}, {3.580791242029183*^9, 3.580791250297183*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Disclaimer", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}}],

Cell["\<\
Date: June 21, 2013.

This file was created by: Matthew Lorig, Stefano Pagliarani and Andrea \
Pascucci.

These Mathematica notebooks are provided on an \[OpenCurlyDoubleQuote]as is\
\[CloseCurlyDoubleQuote] basis without warranty of any kind, express or \
implied. Under no circumstances and under no legal theory, whether in tort, \
contract, or otherwise, shall the authors be liable to you or to any other \
person for any indirect, special, incidental, or consequential damages or \
losses. If you do not agree with these terms, then you are advised to not use \
the notebooks.

Please do no redistribute these notebooks.  If you wish to endorse the \
notebooks, then please link to the web-pages of the authors:
http://www.princeton.edu/~mlorig/
http://www.math.unipd.it/~stefanop/
http://www.dm.unibo.it/~pascucci/\
\>", "Text",
 CellChangeTimes->{{3.5127369954359856`*^9, 3.512737125359417*^9}, {
   3.5127371655637164`*^9, 3.5127371663597617`*^9}, {3.512814058730217*^9, 
   3.512814058891226*^9}, 3.526199505602*^9, 3.5268335032155323`*^9, {
   3.5272388928125*^9, 3.527238893671875*^9}, {3.5804506352987995`*^9, 
   3.580450646016018*^9}, 3.5804510585431423`*^9, {3.5804621340814085`*^9, 
   3.5804621352670107`*^9}, {3.580791238955983*^9, 3.580791239018383*^9}}],

Cell[TextData[StyleBox["", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}, 
   3.580451009169056*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"2", "y"}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cc", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", 
    RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"y", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]\[Alpha]", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Compute"}]}]}]}]}]}]}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Coefficients", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], "  ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["aa", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"4", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["bb", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"4", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["cc", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"4", "!"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"0", ",", "4"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Alpha]\[Alpha]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x0", ",", "y0"}], "]"}], "/", 
     RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Get"}]}]}]}]}]}]}], " ", "Implied", " ", "Vol", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Expansion", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Define"}]}]}]}]}]}]}], " ", "3", "rd", " ", 
    "order", " ", "Implied", " ", "Vol", " ", "Expansion", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]0", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]00", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]1", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]10", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]01", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]2", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]20", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]11", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]02", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]3", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]30", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]21", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]12", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]03", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
     "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", " ", "Exact"}]}]}]}]}]}]}], " ", "SABR", " ", 
    "implied", " ", "volatility", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]SABR", "  ", "--"}], "--"}], "--"}], "--"}], 
    RowBox[{"--", 
     RowBox[{"--", "--"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"NOTE", ":", " ", 
     RowBox[{
     "exact", " ", "price", " ", "and", " ", "implied", " ", "vol", " ", 
      "only", " ", "valied", " ", "for", " ", "\[Rho]"}]}], " ", "=", " ", 
    "0"}], " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V0", "=", 
   RowBox[{
    RowBox[{"Exp", "[", "y", "]"}], "/", "\[Delta]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"qK", "[", "k_", "]"}], "=", 
   FractionBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Beta]"}], ")"}], "k"}], "]"}], 
    RowBox[{"1", "-", "\[Beta]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"q0", "[", "x_", "]"}], "=", 
   FractionBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Beta]"}], ")"}], "x"}], "]"}], 
    RowBox[{"1", "-", "\[Beta]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bbbb", "[", 
    RowBox[{"x_", ",", "k_"}], "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"qK", "[", "k", "]"}], "^", "2"}], "+", 
     RowBox[{
      RowBox[{"q0", "[", "x", "]"}], "^", "2"}]}], 
    RowBox[{"2", 
     RowBox[{"qK", "[", "k", "]"}], " ", 
     RowBox[{"q0", "[", "x", "]"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Xi]0", "[", 
    RowBox[{"x_", ",", "k_", ",", "V_", ",", "\[Phi]_"}], "]"}], "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"qK", "[", "k", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"q0", "[", "x", "]"}], "^", "2"}], "+", 
       RowBox[{"V", "^", "2"}], "+", 
       RowBox[{"V0", "^", "2"}]}], 
      RowBox[{"2", " ", "V", " ", "V0"}]], "-", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"qK", "[", "k", "]"}], " ", 
        RowBox[{"q0", "[", "x", "]"}]}], 
       RowBox[{"V", " ", "V0"}]], 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Xi]1", "[", 
    RowBox[{"x_", ",", "k_", ",", "V_", ",", "\[Psi]_"}], "]"}], "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"qK", "[", "k", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"q0", "[", "x", "]"}], "^", "2"}], "+", 
       RowBox[{"V", "^", "2"}], "+", 
       RowBox[{"V0", "^", "2"}]}], 
      RowBox[{"2", " ", "V", " ", "V0"}]], "+", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"qK", "[", "k", "]"}], " ", 
        RowBox[{"q0", "[", "x", "]"}]}], 
       RowBox[{"V", " ", "V0"}]], 
      RowBox[{"Cosh", "[", "\[Psi]", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Nu]", "=", 
    FractionBox[
     RowBox[{"-", "1"}], 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Beta]"}], ")"}]}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Call", "[", 
     RowBox[{"t_", ",", "x_", ",", "k_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"Exp", "[", 
        RowBox[{"x", "+", "k"}], "]"}]], 
      FractionBox[
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"\[Delta]", "^", "2"}]}], " ", 
         RowBox[{"t", "/", "8"}]}], "]"}], 
       SqrtBox[
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"\[Delta]", "^", "2"}], "t"}]]], 
      RowBox[{"(", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         FractionBox["1", "\[Pi]"], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            FractionBox["1", "V"], 
            RowBox[{
             RowBox[{"(", 
              FractionBox["V", "V0"], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "/", "2"}], ")"}]}], 
            FractionBox[
             RowBox[{
              RowBox[{"Sin", "[", "\[Phi]", "]"}], 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Nu]", "]"}], "\[Phi]"}], "]"}]}], 
             RowBox[{
              RowBox[{"bbbb", "[", 
               RowBox[{"x", ",", "k"}], "]"}], "-", 
              RowBox[{"Cos", "[", "\[Phi]", "]"}]}]], 
            RowBox[{"Exp", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"\[Xi]0", "[", 
                RowBox[{"x", ",", "k", ",", "V", ",", "\[Phi]"}], "]"}], "^", 
               "2"}], 
              RowBox[{"2", " ", 
               RowBox[{"\[Delta]", "^", "2"}], "t"}]], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Phi]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"V", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "+", 
        RowBox[{
         FractionBox[
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"Abs", "[", "\[Nu]", "]"}], " ", "\[Pi]"}], "]"}], 
          "\[Pi]"], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            FractionBox["1", "V"], 
            RowBox[{
             RowBox[{"(", 
              FractionBox["V", "V0"], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "/", "2"}], ")"}]}], 
            FractionBox[
             RowBox[{"Sinh", "[", "\[Psi]", "]"}], 
             RowBox[{
              RowBox[{"bb", "[", 
               RowBox[{"x", ",", "k"}], "]"}], "-", 
              RowBox[{"Cosh", "[", "\[Psi]", "]"}]}]], 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Abs", "[", "\[Nu]", "]"}]}], "\[Psi]"}], "]"}], 
            RowBox[{"Exp", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"\[Xi]1", "[", 
                RowBox[{"x", ",", "k", ",", "V", ",", "\[Psi]"}], "]"}], "^", 
               "2"}], 
              RowBox[{"2", " ", 
               RowBox[{"\[Delta]", "^", "2"}], " ", "t"}]], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Psi]", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"V", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", ")"}]}], "+", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", "x", "]"}], "-", 
        RowBox[{"Exp", "[", "k", "]"}]}], ",", "0"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", "[", "z_", "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"NumericQ", "[", "z", "]"}], "&&", 
        RowBox[{"z", "<", "0"}]}], ",", 
       RowBox[{"Erfc", "[", 
        RowBox[{
         RowBox[{"-", "z"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}], ",", 
       RowBox[{"1", "+", 
        RowBox[{"Erf", "[", 
         RowBox[{"z", "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}], "]"}]}]}], "]"}], "/", "2"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PBS", "[", 
    RowBox[{"t_", ",", "x_", ",", "k_", ",", "\[Sigma]_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d1", ",", "d2"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"d1", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "k", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Sigma]", "^", "2"}], "/", "2"}], ")"}], "t"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}]}], ";", "\n", "\t", 
      RowBox[{"d2", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "k", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Sigma]", "^", "2"}]}], "/", "2"}], ")"}], "t"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}]}], ";", "\n", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", "x", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "d1", "]"}]}], "-", 
       RowBox[{
        RowBox[{"Exp", "[", "k", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "d2", "]"}]}]}]}]}], "\n", "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImpVol", "[", 
    RowBox[{"CallPrice_", ",", "t_", ",", "x_", ",", "k_"}], "]"}], ":=", " ", 
   RowBox[{"FinancialDerivative", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<European\>\"", ",", " ", "\"\<Call\>\""}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<StrikePrice\>\"", " ", "->", " ", 
        RowBox[{"Exp", "[", "k", "]"}]}], ",", " ", 
       RowBox[{"\"\<Expiration\>\"", " ", "->", " ", "t"}], ",", " ", 
       RowBox[{"\"\<Value\>\"", " ", "->", " ", "CallPrice"}]}], "}"}], ",", 
     "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<InterestRate\>\"", " ", "->", " ", "0"}], ",", " ", 
       RowBox[{"\"\<CurrentPrice\>\"", " ", "\[Rule]", 
        RowBox[{"Exp", "[", "x", "]"}]}], ",", " ", 
       RowBox[{"\"\<Dividend\>\"", " ", "->", " ", "0"}]}], "}"}], ",", " ", 
     "\"\<ImpliedVolatility\>\""}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]SABR", "[", 
     RowBox[{"t_", ",", "x_", ",", "k_"}], "]"}], ":=", 
    RowBox[{"Quiet", "[", 
     RowBox[{"ImpVol", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"Call", "[", 
         RowBox[{"t", ",", "x", ",", "k"}], "]"}], "]"}], ",", "t", ",", "x", 
       ",", "k"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"-", " ", "Hagan"}]}]}]}], " ", "SABR", " ", 
    RowBox[{"Expansion", " ", "--"}], 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"-", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", "-"}]}]}]}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exp", "[", "k", "]"}], "+", 
      RowBox[{"Exp", "[", "x", "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]", "=", 
   RowBox[{"\[Delta]", " ", 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{"-", "y"}], "]"}], 
     RowBox[{"\[Beta]", "-", "1"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Beta]"}], ")"}], "k"}], "]"}], "-", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Beta]"}], ")"}], "x"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], "=", 
   RowBox[{"\[Beta]", "/", "fff"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], "=", 
   RowBox[{"\[Beta]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Beta]", "-", "1"}], ")"}], "/", 
     RowBox[{"fff", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ddd", "[", "z_", "]"}], "=", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Rho]", " ", "\[Zeta]"}], " ", "+", " ", 
        RowBox[{"\[Zeta]", "^", "2"}]}]], "+", "\[Zeta]", "-", "\[Rho]"}], 
     RowBox[{"1", "-", "\[Rho]"}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]Hagan", "[", 
     RowBox[{"t_", ",", "x_", ",", "k_"}], "]"}], "=", 
    RowBox[{"\[Delta]", " ", 
     FractionBox[
      RowBox[{"x", "-", "k"}], 
      RowBox[{"ddd", "[", "\[Zeta]", "]"}]], 
     RowBox[{"(", 
      RowBox[{"1", "+", " ", 
       RowBox[{"t", " ", 
        RowBox[{"\[Delta]", "^", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"2", 
              SubscriptBox["\[Gamma]", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               SubscriptBox["\[Gamma]", "1"], ")"}], "^", "2"}], "+", 
             RowBox[{"1", "/", 
              RowBox[{"fff", "^", "2"}]}]}], "24"], 
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"Exp", "[", 
               RowBox[{"y", "+", 
                RowBox[{"\[Beta]", " ", "fff"}]}], "]"}], "\[Delta]"], ")"}], 
            "^", "2"}]}], "+", 
          FractionBox[
           RowBox[{"\[Rho]", " ", 
            SubscriptBox["\[Gamma]", "1"], 
            RowBox[{"Exp", "[", 
             RowBox[{"y", "+", 
              RowBox[{"\[Beta]", " ", "fff"}]}], "]"}]}], 
           RowBox[{"4", " ", "\[Delta]"}]], "+", 
          FractionBox[
           RowBox[{"2", "-", 
            RowBox[{"3", 
             RowBox[{"\[Rho]", "^", "2"}]}]}], "24"]}], ")"}]}]}], ")"}]}]}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", " ", "Choose"}]}]}]}]}]}]}], " ", "SABR", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"parameters", " ", "--"}], "--"}], "--"}], "--"}], "--"}]}], 
    "-"}], " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]", "=", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "=", 
    RowBox[{"-", "0.8"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"-", "Implied"}]}]}]}]}]}], " ", "Vol", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Plots", " ", "--"}], "--"}], "--"}], "--"}], "--"}], 
     "--"}]}], "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", "x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y0", "=", "y"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Implied Vol: Exact (solid) vs 3rd Order (dashed) vs HKLW \
(dotted)\>\"", ",", "16", ",", "Blue", ",", "Bold"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Time to maturity = \>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"t", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmin", "=", 
   RowBox[{"-", "1.25"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmax", "=", "1.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Sigma]SABR", "[", 
       RowBox[{"t", ",", "x", ",", "k"}], "]"}], ",", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
       "]"}], ",", 
      RowBox[{"\[Sigma]Hagan", "[", 
       RowBox[{"t", ",", "x", ",", "k"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "kmin", ",", "kmax"}], "}"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotPoints", "\[Rule]", "21"}], ",", 
    RowBox[{"MaxRecursion", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", " ", "Print"}]}]}]}]}]}], " ", "Implied", " ", 
    "Volatility", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Formula", " ", "--"}], "--"}], "--"}], "--"}], "--"}], 
       "--"}], "--"}], "--"}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"2", "y"}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cc", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", 
    RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"y", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]\[Alpha]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"To", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["aa", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["aa", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["bb", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["bb", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["cc", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"c", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["cc", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Alpha]\[Alpha]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"3", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"2", "!"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Alpha]", "[", 
       RowBox[{"0", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Alpha]\[Alpha]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "/", 
       RowBox[{"3", "!"}]}]}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]0", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]00", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]1", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]10", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]01", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]2", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]20", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]11", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]02", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]3", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]30", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]21", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]12", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]03", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]0", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]1", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]2", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]3", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Third Order Implied Volatility Approximation\>\"", ",", "16", ",", 
    "Blue", ",", "Bold"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<\[Sigma] = \!\(\*SubscriptBox[\(\[Sigma]\), \(0\)]\) + \
\!\(\*SubscriptBox[\(\[Sigma]\), \(1\)]\) + \!\(\*SubscriptBox[\(\[Sigma]\), \
\(2\)]\) + \!\(\*SubscriptBox[\(\[Sigma]\), \(3\)]\)\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(0\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(1\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(2\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<------ \!\(\*SubscriptBox[\(\[Sigma]\), \(3\)]\) ------\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "0", ",", "y", ",", "0", ",", "y", ",", "z"}], "]"}], 
     "/.", "To"}], ",", "z", ",", "Simplify"}], "]"}], "/.", 
  RowBox[{"z", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{"k", "-", "x"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<----------------\>\"", "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"-", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Manipulate", " ", "--"}], "--"}], "--"}], "--"}], 
               "--"}], "--"}], "--"}], "--"}]}]}]}]}]}]}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"2", "y"}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cc", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", 
    RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"y", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "1"}], ")"}], "x"}]}], "]"}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]\[Alpha]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{"\[Delta]", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["aa", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"0", ",", "4"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "4"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["bb", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"0", ",", "4"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["bb", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "4"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["cc", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", 
    RowBox[{"0", ",", "4"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["cc", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "4"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[Alpha]\[Alpha]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x0", ",", "y0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"2", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"4", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"4", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{"2", "!"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"3", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "4"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "4"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x0", ",", "y0"}], "]"}], "/", 
    RowBox[{"4", "!"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<ImpVolAlgebra-1.00.mx\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "filename", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]0", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]00", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]1", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]10", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]01", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]2", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]20", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]11", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]02", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]3", "[", 
    RowBox[{"t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_"}], 
    "]"}], "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]30", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]21", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]12", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"\[Sigma]03", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", 
     RowBox[{
     "t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_", ",", 
      "\[Delta]_", ",", "\[Beta]_", ",", "\[Rho]_"}], "]"}], "=", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]0", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]1", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]2", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}], "+", "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]3", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "x0", ",", "y0", ",", "k"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"-", " ", "Hagan"}]}]}]}], " ", "SABR", " ", 
    RowBox[{"Expansion", " ", "--"}], 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"-", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", "-"}]}]}]}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fff", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exp", "[", "k", "]"}], "+", 
      RowBox[{"Exp", "[", "x", "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]", "=", 
   RowBox[{"\[Delta]", " ", 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{"-", "y"}], "]"}], 
     RowBox[{"\[Beta]", "-", "1"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Beta]"}], ")"}], "k"}], "]"}], "-", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Beta]"}], ")"}], "x"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], "=", 
   RowBox[{"\[Beta]", "/", "fff"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], "=", 
   RowBox[{"\[Beta]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Beta]", "-", "1"}], ")"}], "/", 
     RowBox[{"fff", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ddd", "[", "z_", "]"}], "=", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Rho]", " ", "\[Zeta]"}], " ", "+", " ", 
        RowBox[{"\[Zeta]", "^", "2"}]}]], "+", "\[Zeta]", "-", "\[Rho]"}], 
     RowBox[{"1", "-", "\[Rho]"}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]Hagan", "[", 
     RowBox[{
     "t_", ",", "x_", ",", "y_", ",", "x0_", ",", "y0_", ",", "k_", ",", 
      "\[Delta]_", ",", "\[Beta]_", ",", "\[Rho]_"}], "]"}], "=", 
    RowBox[{"\[Delta]", " ", 
     FractionBox[
      RowBox[{"x", "-", "k"}], 
      RowBox[{"ddd", "[", "\[Zeta]", "]"}]], 
     RowBox[{"(", 
      RowBox[{"1", "+", " ", 
       RowBox[{"t", " ", 
        RowBox[{"\[Delta]", "^", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"2", 
              SubscriptBox["\[Gamma]", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               SubscriptBox["\[Gamma]", "1"], ")"}], "^", "2"}], "+", 
             RowBox[{"1", "/", 
              RowBox[{"fff", "^", "2"}]}]}], "24"], 
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"Exp", "[", 
               RowBox[{"y", "+", 
                RowBox[{"\[Beta]", " ", "fff"}]}], "]"}], "\[Delta]"], ")"}], 
            "^", "2"}]}], "+", 
          FractionBox[
           RowBox[{"\[Rho]", " ", 
            SubscriptBox["\[Gamma]", "1"], 
            RowBox[{"Exp", "[", 
             RowBox[{"y", "+", 
              RowBox[{"\[Beta]", " ", "fff"}]}], "]"}]}], 
           RowBox[{"4", " ", "\[Delta]"}]], "+", 
          FractionBox[
           RowBox[{"2", "-", 
            RowBox[{"3", 
             RowBox[{"\[Rho]", "^", "2"}]}]}], "24"]}], ")"}]}]}], ")"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x0", "=", "x"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmin", "=", 
   RowBox[{"-", "0.75"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kmax", "=", "0.75"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"Style", "[", 
   RowBox[{
   "\"\<Implied Vol: 3rd Order (dashed) vs HKLW (dotted)\>\"", ",", "16", ",",
     "Blue", ",", "Bold"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]", "[", 
        RowBox[{
        "t", ",", "x", ",", "y", ",", "x0", ",", "y", ",", "k", ",", 
         "\[Delta]", ",", "\[Beta]", ",", "\[Rho]"}], "]"}], ",", 
       RowBox[{"\[Sigma]Hagan", "[", 
        RowBox[{
        "t", ",", "x", ",", "y", ",", "x0", ",", "y", ",", "k", ",", 
         "\[Delta]", ",", "\[Beta]", ",", "\[Rho]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "kmin", ",", "kmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.0"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Delta]", ",", "0.2", ",", "0.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0.1", ",", "1.0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"Log", "[", "0.1", "]"}], ",", 
     RowBox[{"Log", "[", "0.3", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Rho]", ",", 
     RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0.1", ",", "1.00"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5764919506094313`*^9, 3.5764919551766925`*^9}, {
   3.5764920277388425`*^9, 3.5764923793689547`*^9}, {3.57649243365906*^9, 
   3.5764924611686335`*^9}, {3.5764925092163815`*^9, 3.5764925165408*^9}, {
   3.576492573216042*^9, 3.576492575420168*^9}, {3.5764926294472585`*^9, 
   3.576492858037333*^9}, {3.5764929496925755`*^9, 3.5764929915949717`*^9}, {
   3.5764930233557887`*^9, 3.576493070042459*^9}, {3.5764931031483526`*^9, 
   3.5764931936075263`*^9}, {3.5764932366559887`*^9, 
   3.5764932372540226`*^9}, {3.576493280358488*^9, 3.576493334976612*^9}, {
   3.576493370408639*^9, 3.5764933944110117`*^9}, 3.5764934345293064`*^9, {
   3.576493472324468*^9, 3.5764935165439973`*^9}, {3.5764935607595263`*^9, 
   3.576493622247043*^9}, {3.576493657747074*^9, 3.5764936578310785`*^9}, {
   3.5764939624475017`*^9, 3.5764939842747498`*^9}, {3.5764940931489773`*^9, 
   3.576494117521371*^9}, {3.576494164550061*^9, 3.5764942686680164`*^9}, {
   3.5764943035230103`*^9, 3.57649438744281*^9}, {3.5764944302792597`*^9, 
   3.5764944308122907`*^9}, {3.576494525762721*^9, 3.576494572489394*^9}, {
   3.576494615017826*^9, 3.576494679571519*^9}, {3.576494720746874*^9, 
   3.5764947664904904`*^9}, {3.5764948084178886`*^9, 
   3.5764948190294952`*^9}, {3.5764948547825403`*^9, 3.576494887717424*^9}, {
   3.5764949811417675`*^9, 3.576495095613315*^9}, {3.5764951328274436`*^9, 
   3.576495204115521*^9}, {3.5764952366803837`*^9, 3.576495285240161*^9}, {
   3.5764953674918656`*^9, 3.576495398809657*^9}, {3.5764954323525753`*^9, 
   3.576495507575878*^9}, {3.5764955383596387`*^9, 3.5764955661242266`*^9}, {
   3.5764957032410693`*^9, 3.5764957208610773`*^9}, {3.57649583263247*^9, 
   3.576495834495577*^9}, {3.5764958874336042`*^9, 3.576495889610729*^9}, 
   3.576495945981953*^9, {3.576496604981646*^9, 3.5764966287680063`*^9}, {
   3.5764966949787936`*^9, 3.5764967599155073`*^9}, {3.5764968247122135`*^9, 
   3.5764968507927055`*^9}, {3.576496894895228*^9, 3.5764970320780745`*^9}, {
   3.57649709423863*^9, 3.576497095835721*^9}, {3.576497161829496*^9, 
   3.5764971765593386`*^9}, {3.5764972116183434`*^9, 3.576497236968794*^9}, {
   3.576497354937541*^9, 3.5764974576074133`*^9}, {3.5764975016959352`*^9, 
   3.576497502343972*^9}, {3.576497563460468*^9, 3.576497578307317*^9}, {
   3.57649762363891*^9, 3.5764976442300873`*^9}, {3.576497676316923*^9, 
   3.5764977401235723`*^9}, {3.5764977799548507`*^9, 3.576497780278869*^9}, 
   3.5764978185650587`*^9, 3.576497855809189*^9, 3.576497888291047*^9, {
   3.5766031700598197`*^9, 3.5766032387127466`*^9}, {3.5766877281742673`*^9, 
   3.576687731841477*^9}, {3.576688604564394*^9, 3.5766886244725323`*^9}, 
   3.576767064755424*^9, {3.5767672043404074`*^9, 3.5767672747464347`*^9}, {
   3.5767673245832853`*^9, 3.5767673273534436`*^9}, {3.576767366401677*^9, 
   3.57676740561592*^9}, {3.576767492264876*^9, 3.576767545920945*^9}, {
   3.5767676280726438`*^9, 3.5767676556872234`*^9}, {3.5767677536718273`*^9, 
   3.5767677589171276`*^9}, {3.5767677901869164`*^9, 3.576767851462421*^9}, {
   3.577111354538566*^9, 3.577111355095598*^9}, {3.5771113966099725`*^9, 
   3.577111422705465*^9}, {3.577111453201209*^9, 3.5771115495757217`*^9}, {
   3.5771115980964966`*^9, 3.577111658719964*^9}, 3.5771116923898897`*^9, {
   3.5771117257988005`*^9, 3.577111751151251*^9}, {3.5771118183830967`*^9, 
   3.577111824001418*^9}, {3.577111879974619*^9, 3.5771119094683065`*^9}, {
   3.577111941691149*^9, 3.577111945573371*^9}, {3.577111982672493*^9, 
   3.577111994228154*^9}, {3.5771120583528223`*^9, 3.577112122119469*^9}, {
   3.577112163687847*^9, 3.5771121822339077`*^9}, 3.577112233537842*^9, 
   3.577112284312746*^9, {3.57711233368157*^9, 3.577112389348754*^9}, 
   3.577112440201662*^9, {3.577112490058514*^9, 3.5771125047193527`*^9}, {
   3.577112549734927*^9, 3.5771125575033717`*^9}, {3.5771126189398856`*^9, 
   3.577112646551465*^9}, 3.5771126791843314`*^9, {3.57711278283426*^9, 
   3.577112783933323*^9}, {3.577965802643202*^9, 3.5779658107956686`*^9}, {
   3.577965854723181*^9, 3.577965886299987*^9}, {3.577965923292103*^9, 
   3.57796594212218*^9}, {3.577966034738477*^9, 3.577966041570868*^9}, {
   3.577966117601217*^9, 3.5779662203900957`*^9}, {3.577966265777692*^9, 
   3.577966278404414*^9}, {3.577966433794302*^9, 3.5779665143919115`*^9}, {
   3.577966564899801*^9, 3.5779666498056574`*^9}, {3.577966685027672*^9, 
   3.5779668133700123`*^9}, {3.577966854200348*^9, 3.5779670275532627`*^9}, {
   3.5779671261339016`*^9, 3.577967142960864*^9}, {3.5779672035913315`*^9, 
   3.577967209487669*^9}, {3.5779673279674454`*^9, 3.577967345462446*^9}, {
   3.577967600100011*^9, 3.5779676262455063`*^9}, {3.577967719808858*^9, 
   3.5779677234550667`*^9}, {3.5779678087209435`*^9, 3.577967858391784*^9}, {
   3.577967980854789*^9, 3.577968028690525*^9}, {3.5779681031267824`*^9, 
   3.577968139766878*^9}, {3.577968429868471*^9, 3.5779684334786773`*^9}, {
   3.57796895243336*^9, 3.5779689590187364`*^9}, {3.5779690638947353`*^9, 
   3.5779690676229486`*^9}, {3.5779691425682344`*^9, 
   3.5779691775122337`*^9}, {3.5779692381727033`*^9, 
   3.5779692497353644`*^9}, {3.5779693170972176`*^9, 
   3.5779693466149054`*^9}, {3.577969439537221*^9, 3.5779694585253067`*^9}, {
   3.577969549981538*^9, 3.5779695556448617`*^9}, {3.5779696140372014`*^9, 
   3.577969615012257*^9}, {3.5779697227004166`*^9, 3.5779697556663017`*^9}, {
   3.5779698323006854`*^9, 3.577969837150963*^9}, {3.5779699505084467`*^9, 
   3.5779699809071856`*^9}, {3.5797027173212166`*^9, 
   3.5797027518181896`*^9}, {3.5797028663537407`*^9, 3.579703018214427*^9}, {
   3.5797030528244066`*^9, 3.5797033611210403`*^9}, {3.579703403551467*^9, 
   3.579703494584674*^9}, {3.5797035260374727`*^9, 3.5797035370841045`*^9}, {
   3.579703612997446*^9, 3.5797036139765024`*^9}, {3.5797036893648143`*^9, 
   3.5797037506793213`*^9}, {3.579703815988057*^9, 3.579703816466084*^9}, {
   3.5797038518681087`*^9, 3.5797038806727567`*^9}, {3.579703922270136*^9, 
   3.579703976587242*^9}, {3.5797040720447025`*^9, 3.579704111468957*^9}, 
   3.5797043274403105`*^9, {3.579707816691884*^9, 3.5797078400802217`*^9}, {
   3.5797092560342093`*^9, 3.57970926320562*^9}, 3.579790650880903*^9, {
   3.5797906948824196`*^9, 3.579790750000572*^9}, 3.579792196493307*^9, {
   3.579878742948166*^9, 3.5798787652924438`*^9}, 3.580461789227203*^9, {
   3.580745673439046*^9, 3.5807459451535873`*^9}, {3.5807460055780435`*^9, 
   3.580746053094761*^9}, {3.580746133349352*^9, 3.580746167363297*^9}, 
   3.580746228839813*^9, {3.580746315307759*^9, 3.580746366920711*^9}, {
   3.580746404279848*^9, 3.580746424673014*^9}, {3.580746503242508*^9, 
   3.580746525808799*^9}, {3.580788965058243*^9, 3.5807889808146467`*^9}, {
   3.580789095146061*^9, 3.580789159543687*^9}, {3.5807892439251685`*^9, 
   3.5807892451887846`*^9}}],

Cell[BoxData[
 StyleBox["\<\"Implied Vol: Exact (solid) vs 3rd Order (dashed) vs HKLW \
(dotted)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.5807912676599827`*^9}}],

Cell[BoxData["\<\"Time to maturity = \"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.5807912676599827`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.5807912676599827`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAvxBy3v//879cFLFxhmnlP7Bds1+O
E/K/8Z/Cmjel5D/NO8TcYfvvv0x4ifZ11eM/XjyWrmgW7L8kjt4pkBjjP+CJ
qQH+ROi/hHkSZnxk4j/tvZdvuyDkv64gd95Lp+E/HnL6kTpD4L9vr5k98/zg
P7QZcJ7DJdi/CnBv86xL4D8c0ts2XtjPvzqF0M1ZS98/YnGpAjyAwL/UjCtx
OiXeP8yWqg7jolE/8jVsBaf43D9ZNiR6gVe/P1Z7BSCK8ts/Zq0BrwHmzj/G
MjD0EATbP7vSwhrRtdc/Zy8p1BgX2j96zhv1HWvfP/tOaPkrT9k/kn7fTA3j
4z8wtHAA+43YP/bI7x39/Oc/MSDmDQbo1z81k4s6K9DrP4GhgJDXYdc/6nZM
PDH27z8G31oEp+XWPz1tzMS66vE/WzowBmCE1j+/EHLe///zPxLBLND4LdY/
rL+zAw==
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAvxBy3v//879bPK5evFPlP7Bds1+O
E/K/LjkZBAuV5D/NO8TcYfvvv1ijI1rGyeM/XjyWrmgW7L+m0tqn4Q/jP+CJ
qQH+ROi/OxBCU+dd4j/tvZdvuyDkv5RjiK5MouE/HnL6kTpD4L+2RT7p+fjg
P7QZcJ7DJdi/LQys5nhI4D8c0ts2XtjPv7GTLvD5Rd8/YnGpAjyAwL86wntE
eSDeP8yWqg7jolE/VDPfNjf03D9ZNiR6gVe/P6fjmBob7ts/Zq0BrwHmzj9J
/B9jav/aP7vSwhrRtdc/KTvUTzwS2j96zhv1HWvfPwFiy6SmStk/kn7fTA3j
4z9Vqw9IaovYP/bI7x39/Oc/I78r6YPq1z81k4s6K9DrP4TI4cmybdc/6nZM
PDH27z9N2RufPwPXPz1tzMS66vE/hB9LcVS81j+/EHLe///zPzhhL2sckNY/
zyuzRg==
     "]]}, 
   {GrayLevel[0], Dashing[{0, Small}], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAvxBy3v//878hrA3+CpPlP7Bds1+O
E/K/I4qnKsLL5D/NO8TcYfvvv7wrz+TY+OM/XjyWrmgW7L96uXw4EjnjP+CJ
qQH+ROi/iFYg+j6C4j/tvZdvuyDkv0Czyd4twuE/HnL6kTpD4L/zMJS1RBXh
P7QZcJ7DJdi/3YuBLmBh4D8c0ts2XtjPv9akicT+cd8/YnGpAjyAwL/AoxTI
00feP8yWqg7jolE/oIABWlQX3T9ZNiR6gVe/Px05QGoMDtw/Zq0BrwHmzj9S
K7Fg7hzbP7vSwhrRtdc/enZtnaEt2j96zhv1HWvfPwE80EcJZNk/kn7fTA3j
4z+/tVYfkqHYP/bI7x39/Oc/vWMA8OD61z81k4s6K9DrPxqP4chwdNc/6nZM
PDH27z8+jcKBZ/jWPz1tzMS66vE/Ww7/HKWX1j+/EHLe///zP1ABry4uQtY/
LDy0XA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.34},
  Method->{},
  PlotRange->{{-1.25, 1.25}, {0.34655590371677747`, 0.6741995775204296}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791274508383*^9}}],

Cell[BoxData[
 StyleBox["\<\"Third Order Implied Volatility Approximation\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274539583*^9}}],

Cell[BoxData["\<\"\[Sigma] = \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \
\\(0\\)]\\) + \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(1\\)]\\) + \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(2\\)]\\) + \\!\\(\\*SubscriptBox[\\(\
\[Sigma]\\), \\(3\\)]\\)\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274539583*^9}}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(0\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274539583*^9}}],

Cell[BoxData[
 SqrtBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"y", "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791274539583*^9}}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(1\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274539583*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]], " ", 
   "t", " ", "\[Delta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Delta]"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
      "\[Rho]"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"y", "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}], "+", 
      RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], 
        ")"}]}]]]}]]}]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791274601983*^9}}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(2\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274601983*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "x"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["\[Delta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"12", " ", 
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]}]], 
  "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"y", "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], " ", "\[Delta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", "\[Rho]"}], "-", 
      RowBox[{
       SuperscriptBox["\[Delta]", "2"], " ", "\[Rho]"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", "\[Delta]",
        " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]", "-", 
         SuperscriptBox["\[Rho]", "2"]}], ")"}]}]}], ")"}]}], 
   RowBox[{"24", " ", 
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]}]], 
  "-", 
  RowBox[{
   FractionBox["1", "96"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]], " ", 
   "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "t", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", "\[Delta]", " ", 
      "\[Rho]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", "\[Delta]", 
      " ", 
      RowBox[{"(", 
       RowBox[{"12", "-", 
        RowBox[{"12", " ", "\[Beta]"}], "+", 
        RowBox[{"7", " ", "t", " ", 
         SuperscriptBox["\[Delta]", "2"]}]}], ")"}], " ", "\[Rho]"}], "+", 
     RowBox[{
      SuperscriptBox["\[Delta]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "32"}], "-", 
        RowBox[{"5", " ", "t", " ", 
         SuperscriptBox["\[Delta]", "2"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Beta]"}], "+", 
        SuperscriptBox["\[Beta]", "2"], "+", 
        RowBox[{"t", " ", 
         SuperscriptBox["\[Delta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791274945183*^9}}],

Cell[BoxData["\<\"------ \\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(3\\)]\\) \
------\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791274945183*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"y", "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", "t", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "x"}], ")"}], "2"], " ", "\[Delta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"], " ", "\[Rho]"}], 
      "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", "\[Delta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]", "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Delta]", "2"], " ", "\[Rho]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Rho]", "2"]}], ")"}]}]}], ")"}]}], 
   RowBox[{"48", " ", 
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]}]], 
  "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"x", "-", "y", "-", 
      RowBox[{"x", " ", "\[Beta]"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "x"}], ")"}], "3"], " ", 
    SuperscriptBox["\[Delta]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
      RowBox[{"\[Delta]", " ", "\[Rho]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"24", " ", 
    SqrtBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]}]], 
  "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"192", " ", 
     SqrtBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"y", "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"k", "-", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"5", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       "t", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "3"]}], "+", 
      RowBox[{"13", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       "t", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"], " ", "\[Delta]", 
       " ", "\[Rho]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]", " ", 
       RowBox[{"(", 
        RowBox[{"8", "+", 
         RowBox[{"t", " ", 
          SuperscriptBox["\[Delta]", "2"]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       "\[Delta]", " ", "\[Rho]", " ", 
       RowBox[{"(", 
        RowBox[{"26", "+", 
         RowBox[{"26", " ", 
          SuperscriptBox["\[Beta]", "2"]}], "-", 
         RowBox[{"\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{"52", "+", 
            RowBox[{"11", " ", "t", " ", 
             SuperscriptBox["\[Delta]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "t", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"6", " ", "\[Beta]"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Beta]", "2"]}], "+", 
         RowBox[{"t", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"y", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
       SuperscriptBox["\[Delta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          RowBox[{"(", 
           RowBox[{"8", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
         RowBox[{"t", " ", 
          SuperscriptBox["\[Delta]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Beta]", " ", 
          RowBox[{"(", 
           RowBox[{"32", "+", 
            RowBox[{"5", " ", "t", " ", 
             SuperscriptBox["\[Delta]", "2"]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", "384"], " ", 
   SqrtBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]]], " ", 
   SuperscriptBox["t", "2"], " ", "\[Delta]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "t", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"], " ", "\[Rho]"}], 
     "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"y", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}]], " ", 
      SuperscriptBox["\[Delta]", "2"], " ", "\[Rho]", " ", 
      RowBox[{"(", 
       RowBox[{"160", "-", 
        RowBox[{"56", " ", "\[Beta]"}], "+", 
        RowBox[{"19", " ", "t", " ", 
         SuperscriptBox["\[Delta]", "2"]}], "-", 
        RowBox[{"36", " ", 
         SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", "\[Delta]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"5", " ", "\[Beta]"}], "-", 
        RowBox[{"14", " ", 
         SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Delta]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"16", "+", 
        RowBox[{"t", " ", 
         SuperscriptBox["\[Delta]", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "\[Rho]", " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"14", " ", 
         SuperscriptBox["\[Beta]", "2"]}], "+", 
        RowBox[{"\[Beta]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "28"}], "+", 
           RowBox[{"5", " ", "t", " ", 
            SuperscriptBox["\[Delta]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"t", " ", 
         SuperscriptBox["\[Delta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "16"}], "+", 
           RowBox[{"15", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}]}]}], ")"}]}]], " ", 
      "\[Delta]", " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Beta]", "2"]}], "+", 
        RowBox[{"52", " ", 
         SuperscriptBox["\[Rho]", "2"]}], "-", 
        RowBox[{"4", " ", "\[Beta]", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"13", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
        RowBox[{"t", " ", 
         SuperscriptBox["\[Delta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "+", 
           RowBox[{"21", " ", 
            SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791276193183*^9}}],

Cell[BoxData["\<\"----------------\"\>"], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791276193183*^9}}],

Cell[BoxData[
 StyleBox["\<\"Implied Vol: 3rd Order (dashed) vs HKLW (dotted)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.5797035401632805`*^9, 3.5797036146695423`*^9, 3.5797037380355983`*^9, 
   3.5797038182021837`*^9, 3.57970388476099*^9, 3.579703978938377*^9, 
   3.579704076010929*^9, 3.5797078509048405`*^9, 3.5797907556728964`*^9, 
   3.579792210032081*^9, 3.579878800738471*^9, 3.5807455477698584`*^9, 
   3.5807459457016187`*^9, 3.580746171384527*^9, 3.5807462328100405`*^9, 
   3.580746434621583*^9, 3.580746531365117*^9, 3.5807889408776226`*^9, 
   3.580788984028329*^9, {3.5807891351449738`*^9, 3.580789161259709*^9}, 
   3.5807892463744*^9, {3.580791253931983*^9, 3.580791276271183*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 
    0.1, $CellContext`y$$ = -2.3025850929940455`, $CellContext`\[Beta]$$ = 
    0.1, $CellContext`\[Delta]$$ = 0.2, $CellContext`\[Rho]$$ = -0.8, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Delta]$$], 0.2, 0.5}, {
      Hold[$CellContext`\[Beta]$$], 0.1, 1.}, {
      Hold[$CellContext`y$$], -2.3025850929940455`, -1.2039728043259361`}, {
      Hold[$CellContext`\[Rho]$$], -0.8, 0.8}, {
      Hold[$CellContext`t$$], 0.1, 1.}}, Typeset`size$$ = {
    360., {118., 122.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Delta]$8618$$ = 
    0, $CellContext`\[Beta]$8619$$ = 0, $CellContext`y$8620$$ = 
    0, $CellContext`\[Rho]$8621$$ = 0, $CellContext`t$8622$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`t$$ = 
        0.1, $CellContext`y$$ = -2.3025850929940455`, $CellContext`\[Beta]$$ = 
        0.1, $CellContext`\[Delta]$$ = 0.2, $CellContext`\[Rho]$$ = -0.8}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$8618$$, 0], 
        Hold[$CellContext`\[Beta]$$, $CellContext`\[Beta]$8619$$, 0], 
        Hold[$CellContext`y$$, $CellContext`y$8620$$, 0], 
        Hold[$CellContext`\[Rho]$$, $CellContext`\[Rho]$8621$$, 0], 
        Hold[$CellContext`t$$, $CellContext`t$8622$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[{
         $CellContext`\[Sigma][$CellContext`t$$, $CellContext`x, \
$CellContext`y$$, $CellContext`x0, $CellContext`y$$, $CellContext`k, \
$CellContext`\[Delta]$$, $CellContext`\[Beta]$$, $CellContext`\[Rho]$$], 
         $CellContext`\[Sigma]Hagan[$CellContext`t$$, $CellContext`x, \
$CellContext`y$$, $CellContext`x0, $CellContext`y$$, $CellContext`k, \
$CellContext`\[Delta]$$, $CellContext`\[Beta]$$, $CellContext`\[Rho]$$]}, \
{$CellContext`k, $CellContext`kmin, $CellContext`kmax}, 
        PlotStyle -> {{Black, Dashed}, {Black, Dotted}}, 
        AxesOrigin -> {0, 0.}], 
      "Specifications" :> {{$CellContext`\[Delta]$$, 0.2, 
         0.5}, {$CellContext`\[Beta]$$, 0.1, 
         1.}, {$CellContext`y$$, -2.3025850929940455`, -1.2039728043259361`}, \
{$CellContext`\[Rho]$$, -0.8, 0.8}, {$CellContext`t$$, 0.1, 1.}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {218., 223.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.577113367363693*^9, 3.5779659679226556`*^9, 3.577966049613328*^9, 
   3.5779662242173147`*^9, 3.5779662790244493`*^9, 3.5779670289943457`*^9, 
   3.5779671539114904`*^9, 3.577967211757799*^9, 3.5779673578981576`*^9, 
   3.5779676297147045`*^9, 3.577967726214224*^9, 3.5779678602078876`*^9, 
   3.5779679966446915`*^9, 3.577968140960946*^9, 3.5779684350037646`*^9, 
   3.577968960724834*^9, 3.5779690706701226`*^9, 3.5779691781572704`*^9, 
   3.577969251241451*^9, 3.577969348806031*^9, 3.577969459125341*^9, 
   3.577969557994996*^9, 3.577969617633407*^9, 3.577969756763365*^9, 
   3.5779698390020685`*^9, 3.5779699841783724`*^9, 3.5797035401652803`*^9, 
   3.579703614671542*^9, 3.5797037380375986`*^9, 3.5797038182041836`*^9, 
   3.579703884764991*^9, 3.579703978940377*^9, 3.5797040760129294`*^9, 
   3.5797078509068413`*^9, 3.5797907556758966`*^9, 3.5797922100360813`*^9, 
   3.5798788007404714`*^9, 3.580745547771858*^9, 3.580745945703619*^9, 
   3.5807461713875275`*^9, 3.5807462328120403`*^9, 3.5807464346265836`*^9, 
   3.580746531369117*^9, 3.5807889408776226`*^9, 3.580788984028329*^9, {
   3.5807891351449738`*^9, 3.580789161259709*^9}, 3.5807892463744*^9, {
   3.580791253931983*^9, 3.580791276271183*^9}}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1690, 945},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[550, 20, 2690, 76, 436, "Input"],
Cell[CellGroupData[{
Cell[3265, 100, 173, 3, 68, "Section"],
Cell[3441, 105, 1284, 25, 220, "Text"],
Cell[4728, 132, 189, 4, 68, "Section"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4954, 141, 108506, 3448, 7795, "Input"],
Cell[113463, 3591, 949, 19, 26, "Print"],
Cell[114415, 3612, 657, 9, 23, "Print"],
Cell[115075, 3623, 1273, 18, 31, "Output"],
Cell[116351, 3643, 3301, 62, 253, "Output"],
Cell[119655, 3707, 924, 18, 26, "Print"],
Cell[120582, 3727, 858, 12, 23, "Print"],
Cell[121443, 3741, 701, 10, 23, "Print"],
Cell[122147, 3753, 1510, 27, 40, "Output"],
Cell[123660, 3782, 701, 10, 23, "Print"],
Cell[124364, 3794, 2934, 76, 63, "Output"],
Cell[127301, 3872, 701, 10, 23, "Print"],
Cell[128005, 3884, 6600, 190, 104, "Output"],
Cell[134608, 4076, 701, 10, 23, "Print"],
Cell[135312, 4088, 13318, 387, 205, "Output"],
Cell[148633, 4477, 652, 9, 23, "Print"],
Cell[149288, 4488, 928, 18, 26, "Print"],
Cell[150219, 4508, 4376, 75, 490, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature PvTGi6QR@q4xQCg80X#J43px *)
